pub struct CurrentDirGuard { /* private fields */ }Expand description
A guard used to indicate that the current working directory is locked. Returned by lock_current_dir. This will restore and unlock the working directory on drop.